The tests prefixed with broken_ were historically part of Gourmet.

They are broken and haven't been looked at. Some may be fixed, some are deprecated due to heavy changes since they were implemented.
This directory is excluded from the CI runner.

It does not mean that they can be freely deleted. Each test file should be assayed and fixed, if possible!
